@@ -8,7 +8,7 @@ import base64
 import json
 import socket
 import asyncio
-import sys
+import threading
 
 # TODO: $iothub/methods/POST/# is unnecessary in topics
 # TODO: on_settings does not work
@@ -118,19 +118,22 @@ class Module:
 
         print("IoT module connected", flush=True)
 
-        def on_restart():
-            async def exit_after(delay):
-                await asyncio.sleep(delay)
-                sys.exit(0)
-            asyncio.create_task(exit_after(1))
-
-        self.on_method('restart', on_restart)
-
         twin: Dict = await self.get_twin()
         self.settings = twin.get('desired')
 
         print("Settings", self.settings, flush=True)
 
+        def on_restart(params):
+            def exit_after():
+                time.sleep(1)
+                raise os._exit(0)
+
+            t1 = threading.Thread(target=exit_after)
+            t1.start()
+            return "Restarting"
+
+        self.on_method('restart', on_restart)
+
     def on_settings(self, cb):
         def handler(topic, payload):
             data = json.loads(payload)
